pub struct ControlFlowGraph<'tcx> {
pub def_id: DefId,
pub tcx: TyCtxt<'tcx>,
pub blocks: Vec<CfgBlock>,
}Expand description
Generic MIR control-flow graph container.
This structure intentionally keeps only generic CFG shape and SCC metadata.
Fields
def_id: DefIdDefinition being analyzed.
tcx: TyCtxt<'tcx>Type context from the Rust compiler.
blocks: Vec<CfgBlock>All CFG blocks for the current body.
Implementations
Sourceimpl<'tcx> ControlFlowGraph<'tcx>
impl<'tcx> ControlFlowGraph<'tcx>
Sourcepub fn new(def_id: DefId, tcx: TyCtxt<'tcx>, blocks: Vec<CfgBlock>) -> Self
pub fn new(def_id: DefId, tcx: TyCtxt<'tcx>, blocks: Vec<CfgBlock>) -> Self
Construct a control-flow graph wrapper from prebuilt blocks.
Sourcepub fn block_mut(&mut self, index: usize) -> &mut CfgBlock
pub fn block_mut(&mut self, index: usize) -> &mut CfgBlock
Get a mutable reference to a block by index.
Sourcepub fn terminator(&self, index: usize) -> Option<&Terminator<'tcx>>
pub fn terminator(&self, index: usize) -> Option<&Terminator<'tcx>>
Retrieve the MIR terminator for the block at index on demand.
Returns None only for blocks whose terminator has not yet been
elaborated (which is unusual for optimized MIR).